jactorch.transforms.vision.functional.bbox
==========================================

.. automodule:: jactorch.transforms.vision.functional.bbox

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      affine
      crop
      denormalize_box
      hflip
      normalize_bbox
      pad
      refresh_valid
      resize
      vflip
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: affine

.. autofunction:: crop

.. autofunction:: denormalize_box

.. autofunction:: hflip

.. autofunction:: normalize_bbox

.. autofunction:: pad

.. autofunction:: refresh_valid

.. autofunction:: resize

.. autofunction:: vflip


